package com.ruoyi.szxc.service;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcXcRecard;

/**
 * 巡查记录Service接口
 * 
 * @author hs
 * @date 2024-03-20
 */
public interface ISzxcXcRecardService 
{
    /**
     * 查询巡查记录
     * 
     * @param id 巡查记录主键
     * @return 巡查记录
     */
    public SzxcXcRecard selectSzxcXcRecardById(Long id);

    /**
     * 查询巡查记录列表
     * 
     * @param szxcXcRecard 巡查记录
     * @return 巡查记录集合
     */
    public List<SzxcXcRecard> selectSzxcXcRecardList(SzxcXcRecard szxcXcRecard);

    /**
     * 新增巡查记录
     * 
     * @param szxcXcRecard 巡查记录
     * @return 结果
     */
    public int insertSzxcXcRecard(SzxcXcRecard szxcXcRecard);

    /**
     * 修改巡查记录
     * 
     * @param szxcXcRecard 巡查记录
     * @return 结果
     */
    public int updateSzxcXcRecard(SzxcXcRecard szxcXcRecard);

    /**
     * 批量删除巡查记录
     * 
     * @param ids 需要删除的巡查记录主键集合
     * @return 结果
     */
    public int deleteSzxcXcRecardByIds(Long[] ids);

    /**
     * 删除巡查记录信息
     * 
     * @param id 巡查记录主键
     * @return 结果
     */
    public int deleteSzxcXcRecardById(Long id);
}
